Function to copy input files to their destination folders
Usage
copy_input(x, sourcepath, suffix = NULL, move = FALSE)
Arguments
- x
Filepath or data frame containing the mapping of files to be deleted
- sourcepath
Path to folder containing all input files
- suffix
suffix that might be part of input names that should be deleted
- move
If TRUE files will be moved instead of copied (default=FALSE)
Author
Jan Philipp Dietrich, David Klein