Skip to content

Get one line of user input regardless of whether running interactively or not (via Rscript). (base::readline does not wait for user input when running via Rscript.)

Usage

getLine()

Value

The user input as a string.