Function that applies interfaceplot for a whole model and
all its modules.
Usage
modules_interfaceplot(
x = ".",
modulepath = "modules",
filetype = "png",
targetfolder = NULL,
writetable = TRUE,
includeCore = FALSE,
...
)Arguments
- x
Either the object returned by
codeCheckor the path to the main folder of the model.- modulepath
Path to the modules folder
- filetype
Filetype that should be used (e.g. "png" or "pdf")
- targetfolder
Folder outputs should be written to. If set to NULL outputs will be added to corresponding module folders
- writetable
Logical deciding whether a csv containing the interfaces should be written as well.
- includeCore
Logical to create plot for core or not, default FALSE.
- ...
Optional arguments to
interfaceplot.