Reads all declarations given in a GAMS code and returns them.
Usage
readDeclarations(
file,
unlist = TRUE,
types = c("scalar", "(positive |negative |)variable", "parameter", "table", "equation",
"set")
)Value
Either a list of declared objects or a matrix containing object name, the sets the object depends on and the description.