Skip to content

Input: a file name or a character vector. Output: a character vector of the contents of the file, or the character vector unchanged.

Usage

readFileOrVector(file)

Arguments

file

A file name or a character vector.

Value

A character vector of the inputs of the file.

Author

Mika Pflüger