Functions which allows for interactive selection of scripts/files.
Usage
selectScript(folder = ".", ending = "R")
Arguments
- folder
Folder in which the files/scripts are located which should
be selected from.
- ending
File ending of the files to be selected (without dot)
Value
A vector of paths to files selected by the user
Author
Jan Philipp Dietrich