Checks whether a folder seems to contain modular GAMS code or not.
Examples
is.modularGAMS(system.file("dummymodel",package="gms"))
#> [1] TRUE
Checks whether a folder seems to contain modular GAMS code or not.
is.modularGAMS(system.file("dummymodel",package="gms"))
#> [1] TRUE