Input: a file name or a character vector. Output: a character vector of the contents of the file, or the character vector unchanged.
Input: a file name or a character vector. Output: a character vector of the contents of the file, or the character vector unchanged.