Reads header written in yaml format from a file
Usage
read_yaml_header(file, n = 20)
Arguments
- file
path to the file which contains the YAML header
- n
Number of lines to be read (header must be part of these lines in order to be read)
Value
A list containing the read in information
Author
Jan Philipp Dietrich