Creates a tgz from all files in a directory
Usage
tardir(dir = ".", tarfile = "data.tgz")
Arguments
- dir
directory from which the tar file should be generated
- tarfile
name of the archive the data should be written to (tgz file)
Author
Jan Philipp Dietrich